
/*
  Software serial multple serial test

 Receives from the hardware serial, sends to software serial.
 Receives from software serial, sends to hardware serial.

 The circuit:
 * RX is digital pin 2 (connect to TX of other device)
 * TX is digital pin 3 (connect to RX of other device)

 Note:
 Not all pins on the Mega and Mega 2560 support change interrupts,
 so only the following can be used for RX:
 10, 11, 12, 13, 50, 51, 52, 53, 62, 63, 64, 65, 66, 67, 68, 69

 Not all pins on the Leonardo support change interrupts,
 so only the following can be used for RX:
 8, 9, 10, 11, 14 (MISO), 15 (SCK), 16 (MOSI).

 created back in the mists of time
 modified 25 May 2012
 by Tom Igoe
 based on Mikal Hart's example

 This example code is in the public domain.

 */
#include <SoftwareSerial.h>

SoftwareSerial mySerial(3, 2); // RX, TX
int RTS = 4;
int CTS = 5;

byte counter = 0;

int VRx = A2;
int VRy = A3;
int SW = A4;

int xPosition = 0;
int yPosition = 0;
int SW_state = 0;
uint8_t mapX = 0;
uint8_t mapY = 0;

struct Message {
  bool play_sound: 1;
  bool is_X: 1;
  uint8_t value: 6;
};


void setup()
{
  // Open serial communications and wait for port to open:
  Serial.begin(57600);

  pinMode(VRx, INPUT);
  pinMode(VRy, INPUT);
  pinMode(SW, INPUT_PULLUP); 
  
  while (!Serial) {
    ; // wait for serial port to connect. Needed for Native USB only
  }


  Serial.println("Goodnight moon!");

  // set the data rate for the SoftwareSerial port
  mySerial.begin(57600);
  mySerial.println("Hello, world?");
}


void loop(){ // run over and over 

    xPosition = analogRead(VRx);
    yPosition = analogRead(VRy);
    SW_state = !digitalRead(SW);
    mapX = map(xPosition, 0, 1023, 0, 63);
    mapY = map(yPosition, 0, 1023, 0, 63);
  
    Serial.print("X: ");
    Serial.print(mapX);
    Serial.print(" | Y: ");
    Serial.print(mapY);
    Serial.print(" | Button: ");
    Serial.println(SW_state);

    
    Message msgX{0, 1, mapX};
    Message msgY{0, 0, mapY};
    digitalWrite(RTS, HIGH);
    while (!digitalRead(CTS)) {}
    mySerial.write(*(byte*) &msgX);
    mySerial.write(*(byte*) &msgY);
    mySerial.flush();
    digitalWrite(RTS, LOW);
    Serial.println("Sent");

    delay(1);

}
